@@ -1,13 +1,13 @@
 use v5.10;
 
 package Perl::Version::Bumper;
-$Perl::Version::Bumper::VERSION = '0.235';
+$Perl::Version::Bumper::VERSION = '0.245';
 
 use strict;
 use warnings;
 use version;
 
-use Path::Tiny;
+use Path::Tiny ();
 use PPI::Document;
 use PPI::Token::Operator;
 use PPI::Token::Attribute;
@@ -172,7 +172,7 @@ sub __evaluate {
           : $_->[0] eq '[' ? [ __SUB__->( @$_[ 1 .. $#$_ ] ) ]    # ARRAY
         : $_->[0] eq '{' ? { __SUB__->( @$_[ 1 .. $#$_ ] ) }      # HASH
         : __SUB__->( @$_[ 1 .. $#$_ ] )    # LIST (flattened)
-      : $_,                                  # SCALAR
+      : $_,                                # SCALAR
       @_;
 }
 
@@ -343,79 +343,109 @@ sub _version_stmts {
 }
 
 my %feature_shine = (
+    when_enabled => {
 
-    # the 'bitwise' feature may break bitwise operators,
-    # so disable it when bitwise operators are detected
-    bitwise => sub {
-        my ($doc) = @_;
+        # the 'bitwise' feature may break bitwise operators,
+        # so disable it when bitwise operators are detected
+        bitwise => sub {
+            my ($doc) = @_;
 
-        # this only matters for code using bitwise ops
-        return unless $doc->find(
-            sub {
-                my ( $root, $elem ) = @_;
-                $elem->isa('PPI::Token::Operator') && $elem =~ /\A[&|~^]=?\z/;
-            }
-        );
+            # this only matters for code using bitwise ops
+            return unless $doc->find(
+                sub {
+                    my ( $root, $elem ) = @_;
+                    $elem->isa('PPI::Token::Operator')
+                      && $elem =~ /\A[&|~^]=?\z/;
+                }
+            );
 
-        # the `use VERSION` inserted earlier is always the first one in the doc
-        my $insert_point = ( _version_stmts($doc) )[0];
-        my $indent = $insert_point->previous_sibling
-          && $insert_point->previous_sibling->isa('PPI::Token::Whitespace')
-          ? $insert_point->previous_sibling
-          : '';
-        my $no_feature_bitwise =
-          PPI::Document->new( \"no feature 'bitwise';\n" );
-        $insert_point->insert_after( $_->remove )
-          for $no_feature_bitwise->elements;
+            # the `use VERSION` inserted earlier is always the first in the doc
+            my $insert_point = ( _version_stmts($doc) )[0];
+            my $indent = $insert_point->previous_sibling
+              && $insert_point->previous_sibling->isa('PPI::Token::Whitespace')
+              ? $insert_point->previous_sibling
+              : '';
+            my $no_feature_bitwise =
+              PPI::Document->new( \"no feature 'bitwise';\n" );
+            $insert_point->insert_after( $_->remove )
+              for $no_feature_bitwise->elements;
 
-        # also add an IMPORTANT comment to warn users
-        $insert_point = $insert_point->snext_sibling;
-        my $todo_comment =
-          PPI::Document->new( \( << "TODO_COMMENT" ) );
+            # also add an IMPORTANT comment to warn users
+            $insert_point = $insert_point->snext_sibling;
+            my $todo_comment = PPI::Document->new( \( << "TODO_COMMENT" ) );
 
 $indent# IMPORTANT: Please double-check the use of bitwise operators
 $indent# before removing the `no feature 'bitwise';` line below.
 $indent# See manual pages 'feature' (section "The 'bitwise' feature")
 $indent# and 'perlop' (section "Bitwise String Operators") for details.
 TODO_COMMENT
-        $insert_point->insert_before( $_->remove ) for $todo_comment->elements;
-        $insert_point->insert_before( $indent->clone ) if $indent;
-    },
+            $insert_point->insert_before( $_->remove )
+              for $todo_comment->elements;
+            $insert_point->insert_before( $indent->clone ) if $indent;
+        },
 
-    # the 'signatures' feature needs prototypes to be updated.
-    signatures => sub {
-        my ($doc) = @_;
+        # the 'signatures' feature needs prototypes to be updated.
+        signatures => sub {
+            my ($doc) = @_;
 
-        # find all subs with prototypes
-        my $prototypes = $doc->find('PPI::Token::Prototype');
-        return unless $prototypes;
+            # find all subs with prototypes
+            my $prototypes = $doc->find('PPI::Token::Prototype');
+            return unless $prototypes;
 
-        # and turn them into prototype attributes
-        for my $proto (@$prototypes) {
-            $proto->insert_before( PPI::Token::Operator->new(':') );
-            $proto->insert_before(
-                PPI::Token::Attribute->new("prototype$proto") );
-            $proto->remove;
-        }
-    },
-
-    # the 'fc' feature means CORE::fc is not required
-    fc => sub {
-        my ($doc) = @_;
-
-        # find all occurences of 'CORE::fc'
-        my $core_fc = $doc->find(
-            sub {
-                my ( $root, $elem ) = @_;
-                return !!1 if $elem->isa('PPI::Token::Word') && $elem eq 'CORE::fc';
-                return !!0;
+            # and turn them into prototype attributes
+            for my $proto (@$prototypes) {
+                $proto->insert_before( PPI::Token::Operator->new(':') );
+                $proto->insert_before(
+                    PPI::Token::Attribute->new("prototype$proto") );
+                $proto->remove;
             }
-        );
-        return unless $core_fc;
+        },
 
-        # and replace them by 'fc'
-        $_->replace( PPI::Token::Word->new('fc') ) for @$core_fc;
+        # the 'fc' feature means CORE::fc is not required
+        fc => sub {
+            my ($doc) = @_;
+
+            # find all occurences of 'CORE::fc'
+            my $core_fc = $doc->find(
+                sub {
+                    my ( $root, $elem ) = @_;
+                    return !!1
+                      if $elem->isa('PPI::Token::Word') && $elem eq 'CORE::fc';
+                    return !!0;
+                }
+            );
+            return unless $core_fc;
+
+            # and replace them by 'fc'
+            $_->replace( PPI::Token::Word->new('fc') ) for @$core_fc;
+        },
     },
+
+    when_disabled => {
+
+        # disabling the 'apostrophe_as_package_separator' feature
+        # drops support for apostrophe in package names
+        apostrophe_as_package_separator => sub {
+            my ($doc) = @_;
+
+            # find all names with an apostrophe
+            my $apostrophes = $doc->find(
+                sub {
+                    my ( $root, $elem ) = @_;
+                    $elem->isa('PPI::Token::Word') && $elem =~ /'/;
+                }
+            );
+            return unless $apostrophes;
+
+            # and replace it with double colons
+            for my $word (@$apostrophes) {
+                ( my $colon = "$word" ) =~ s/'/::/g;
+                $word->replace( bless { content => $colon },
+                    'PPI::Token::Word' );
+            }
+        },
+    },
+
 );
 
 # PRIVATE "METHODS"
@@ -539,15 +569,25 @@ sub _cleanup_bundled_features {
     }
 
     # apply some feature shine when crossing the feature enablement boundary
-    for my $feature ( sort grep exists $feature{$_}{enabled}, keys %feature_shine ) {
+    for my $feature ( sort keys %{ $feature_shine{when_enabled} }  ) {
         my $feature_enabled = $feature{$feature}{enabled};
-        $feature_shine{$feature}->($doc)
+        $feature_shine{when_enabled}{$feature}->($doc)
           if $old_num < $feature_enabled         # code from before the feature
           && $version_num >= $feature_enabled    # bumped to after the feature
           && !$enabled_in_code{$feature}         # not enabling the feature
           && !$disabled_in_code{$feature};       # and not disabling the feature
     }
 
+    # apply some feature shine when crossing the feature disablement boundary
+    for my $feature ( sort keys %{ $feature_shine{when_disabled} }  ) {
+        my $feature_disabled = $feature{$feature}{disabled};
+        $feature_shine{when_disabled}{$feature}->($doc)
+          if $old_num < $feature_disabled        # code from before the feature
+          && $version_num >= $feature_disabled   # bumped to after the feature
+          && !$enabled_in_code{$feature}         # not enabling the feature
+          && !$disabled_in_code{$feature};       # and not disabling the feature
+    }
+
     # drop experimental warnings, if any
     for my $warn_line ( _find_include( warnings => $doc, 'no' ) ) {
         my @old_args = _ppi_list_to_perl_list( $warn_line->arguments );
@@ -859,7 +899,7 @@ The constructor will also silently drop any sub-version information
 Return the version (in numeric format) of the feature set recognized
 by this module. It is not possible to bump code over that version.
 
-The current value of C<feature_version> is: C<5.040>.
+The current value of C<feature_version> is: C<5.042>.
 
 =head2 feature_data
 
@@ -1267,7 +1307,7 @@ BEGIN {
 
 =pod
 
-                  5.040 features known    enabled  disabled removed  compat
+                  5.042 features known    enabled  disabled removed  compat
                              say   5.010    5.010                    Perl6::Say 1 Say::Compat 1
                            state   5.010    5.010
                           switch   5.010    5.010    5.036
@@ -1281,18 +1321,22 @@ BEGIN {
                        postderef   5.020    5.024
                     postderef_qq   5.020    5.024
                       signatures   5.020    5.036
-                     refaliasing   5.022
                          bitwise   5.022    5.028
+                     refaliasing   5.022
                    declared_refs   5.026
                         indirect   5.032    5.010    5.036           indirect 0
                              isa   5.032    5.036
-            bareword_filehandles   5.034    5.010    5.038           bareword::filehandles 0
                 multidimensional   5.034    5.010    5.036           multidimensional 0
+            bareword_filehandles   5.034    5.010    5.038           bareword::filehandles 0
                              try   5.034    5.040                    Feature::Compat::Try 1 Syntax::Feature::Try 0 Syntax::Keyword::Try 0
                            defer   5.036                             Feature::Compat::Defer 1 Syntax::Keyword::Defer 0
          extra_paired_delimiters   5.036
-                           class   5.038                             Feature::Compat::Class 1
                      module_true   5.038    5.038
+                           class   5.038                             Feature::Compat::Class 1
+ apostrophe_as_package_separator   5.042    5.010    5.042
+                      smartmatch   5.042    5.010    5.042
+                     keyword_all   5.042
+                     keyword_any   5.042
 
 =cut
 
